==> linkml-0.0.7.tar.gz: linkml-0.0.7/tests/test_biolink_model/output/markdown_no_image/has_output.md <==

# Slot: has_output


holds between a process and a continuant, where the continuant is an output of the process

URI: [biolink:has_output](https://w3id.org/biolink/vocab/has_output)


## Domain and Range

[Occurrent](Occurrent.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [has participant](has_participant.md)

## Children

 *  [molecular activity➞has output](molecular_activity_has_output.md)

## Used by

 * [Behavior](Behavior.md)
 * [BehavioralExposure](BehavioralExposure.md)
 * [BehavioralOutcome](BehavioralOutcome.md)
 * [BiologicalProcess](BiologicalProcess.md)
 * [BiologicalProcessOrActivity](BiologicalProcessOrActivity.md)
 * [Death](Death.md)
 * [MortalityOutcome](MortalityOutcome.md)
 * [PathologicalProcess](PathologicalProcess.md)
 * [PathologicalProcessExposure](PathologicalProcessExposure.md)
 * [PathologicalProcessOutcome](PathologicalProcessOutcome.md)
 * [Pathway](Pathway.md)
 * [PhysiologicalProcess](PhysiologicalProcess.md)
 * [SocioeconomicExposure](SocioeconomicExposure.md)
 * [SocioeconomicOutcome](SocioeconomicOutcome.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | RO:0002234 |
| **Close Mappings:** | | RO:0002353 |
|  | | RO:0002354 |
|  | | RTXKG1:output_of |
| **Narrow Mappings:** | | NCIT:biological_process_has_result_anatomy |
|  | | OBI:0000299 |
|  | | PathWhiz:has_right_element |
|  | | RO:0002296 |
|  | | RO:0002297 |
|  | | RO:0002298 |
|  | | RO:0002299 |
|  | | RO:0002588 |
|  | | RO:0004008 |

==> linkml-1.2.9.tar.gz: linkml-1.2.9/tests/test_biolink_model/output/markdown_no_image/has_output.md <==

# Slot: has output


holds between a process and a continuant, where the continuant is an output of the process

URI: [biolink:has_output](https://w3id.org/biolink/vocab/has_output)


## Domain and Range

[Occurrent](Occurrent.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [has participant](has_participant.md)

## Children

 *  [molecular activity➞has output](molecular_activity_has_output.md)

## Used by

 * [Behavior](Behavior.md)
 * [BehavioralExposure](BehavioralExposure.md)
 * [BehavioralOutcome](BehavioralOutcome.md)
 * [BiologicalProcess](BiologicalProcess.md)
 * [BiologicalProcessOrActivity](BiologicalProcessOrActivity.md)
 * [Death](Death.md)
 * [MortalityOutcome](MortalityOutcome.md)
 * [PathologicalProcess](PathologicalProcess.md)
 * [PathologicalProcessExposure](PathologicalProcessExposure.md)
 * [PathologicalProcessOutcome](PathologicalProcessOutcome.md)
 * [Pathway](Pathway.md)
 * [PhysiologicalProcess](PhysiologicalProcess.md)
 * [SocioeconomicExposure](SocioeconomicExposure.md)
 * [SocioeconomicOutcome](SocioeconomicOutcome.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | RO:0002234 |
| **Close Mappings:** | | RO:0002353 |
|  | | RO:0002354 |
|  | | RTXKG1:output_of |
| **Narrow Mappings:** | | NCIT:R31 |
|  | | OBI:0000299 |
|  | | PathWhiz:has_right_element |
|  | | RO:0002296 |
|  | | RO:0002297 |
|  | | RO:0002298 |
|  | | RO:0002299 |
|  | | RO:0002588 |
|  | | RO:0004008 |
